@@ -145,70 +145,4 @@ clutter_round_to_256ths (float *f)
   *f = roundf ((*f) * 256) / 256;
 }
 
-static inline uint64_t
-ns (uint64_t ns)
-{
-  return ns;
-}
-
-static inline int64_t
-us (int64_t us)
-{
-  return us;
-}
-
-static inline int64_t
-ms (int64_t ms)
-{
-  return ms;
-}
-
-static inline int64_t
-ms2us (int64_t ms)
-{
-  return us (ms * 1000);
-}
-
-static inline int64_t
-us2ns (int64_t us)
-{
-  return ns (us * 1000);
-}
-
-static inline int64_t
-us2ms (int64_t us)
-{
-  return (int64_t) (us / 1000);
-}
-
-static inline int64_t
-ns2us (int64_t ns)
-{
-  return us (ns / 1000);
-}
-
-static inline int64_t
-s2us (int64_t s)
-{
-  return s * G_USEC_PER_SEC;
-}
-
-static inline int64_t
-us2s (int64_t us)
-{
-  return us / G_USEC_PER_SEC;
-}
-
-static inline int64_t
-s2ns (int64_t s)
-{
-  return us2ns (s2us (s));
-}
-
-static inline int64_t
-s2ms (int64_t s)
-{
-  return (int64_t) ms (s * 1000);
-}
-
 G_END_DECLS
