@@ -39,6 +39,3 @@ _cogl_memory_stack_new (size_t initial_size_bytes);
 
 void *
 _cogl_memory_stack_alloc (CoglMemoryStack *stack, size_t bytes);
-
-void
-_cogl_memory_stack_free (CoglMemoryStack *stack);
