@@ -27,7 +27,7 @@
 #include <math.h>
 
 #include "backends/meta-backend-private.h"
-#include "backends/meta-logical-monitor.h"
+#include "backends/meta-logical-monitor-private.h"
 #include "backends/meta-stage-private.h"
 #include "clutter/clutter.h"
 #include "clutter/clutter-mutter.h"
@@ -45,7 +45,7 @@ enum
   PROP_0,
 
   PROP_BACKEND,
-  PROP_DEVICE,
+  PROP_SPRITE,
 
   N_PROPS
 };
@@ -59,7 +59,7 @@ struct _MetaCursorRendererPrivate
   float current_x;
   float current_y;
 
-  ClutterInputDevice *device;
+  ClutterSprite *sprite;
   MetaCursorSprite *displayed_cursor;
   MetaCursorSprite *overlay_cursor;
 
@@ -236,8 +236,8 @@ meta_cursor_renderer_get_property (GObject    *object,
     case PROP_BACKEND:
       g_value_set_object (value, priv->backend);
       break;
-    case PROP_DEVICE:
-      g_value_set_object (value, priv->device);
+    case PROP_SPRITE:
+      g_value_set_object (value, priv->sprite);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -260,8 +260,8 @@ meta_cursor_renderer_set_property (GObject      *object,
     case PROP_BACKEND:
       priv->backend = g_value_get_object (value);
       break;
-    case PROP_DEVICE:
-      priv->device = g_value_get_object (value);
+    case PROP_SPRITE:
+      priv->sprite = g_value_get_object (value);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -321,9 +321,9 @@ meta_cursor_renderer_class_init (MetaCursorRendererClass *klass)
                          G_PARAM_READWRITE |
                          G_PARAM_CONSTRUCT_ONLY |
                          G_PARAM_STATIC_STRINGS);
-  obj_props[PROP_DEVICE] =
-    g_param_spec_object ("device", NULL, NULL,
-                         CLUTTER_TYPE_INPUT_DEVICE,
+  obj_props[PROP_SPRITE] =
+    g_param_spec_object ("sprite", NULL, NULL,
+                         CLUTTER_TYPE_SPRITE,
                          G_PARAM_READWRITE |
                          G_PARAM_CONSTRUCT_ONLY |
                          G_PARAM_STATIC_STRINGS);
@@ -508,12 +508,12 @@ meta_cursor_renderer_update_cursor (MetaCursorRenderer *renderer,
 }
 
 MetaCursorRenderer *
-meta_cursor_renderer_new (MetaBackend        *backend,
-                          ClutterInputDevice *device)
+meta_cursor_renderer_new (MetaBackend   *backend,
+                          ClutterSprite *sprite)
 {
   return g_object_new (META_TYPE_CURSOR_RENDERER,
                        "backend", backend,
-                       "device", device,
+                       "sprite", sprite,
                        NULL);
 }
 
@@ -542,11 +542,14 @@ meta_cursor_renderer_force_update (MetaCursorRenderer *renderer)
 void
 meta_cursor_renderer_update_position (MetaCursorRenderer *renderer)
 {
-  MetaCursorRendererPrivate *priv = meta_cursor_renderer_get_instance_private (renderer);
+  MetaCursorRendererPrivate *priv =
+    meta_cursor_renderer_get_instance_private (renderer);
+  ClutterBackend *clutter_backend =
+    meta_backend_get_clutter_backend (priv->backend);
+  ClutterSeat *seat = clutter_backend_get_default_seat (clutter_backend);
   graphene_point_t pos;
 
-  clutter_seat_query_state (clutter_input_device_get_seat (priv->device),
-                            priv->device, NULL, &pos, NULL);
+  clutter_seat_query_state (seat, priv->sprite, &pos, NULL);
   priv->current_x = pos.x;
   priv->current_y = pos.y;
 
@@ -561,13 +564,13 @@ meta_cursor_renderer_get_cursor (MetaCursorRenderer *renderer)
   return priv->overlay_cursor;
 }
 
-ClutterInputDevice *
-meta_cursor_renderer_get_input_device (MetaCursorRenderer *renderer)
+ClutterSprite *
+meta_cursor_renderer_get_sprite (MetaCursorRenderer *renderer)
 {
   MetaCursorRendererPrivate *priv =
     meta_cursor_renderer_get_instance_private (renderer);
 
-  return priv->device;
+  return priv->sprite;
 }
 
 MetaBackend *
