@@ -45,7 +45,7 @@
 #include <glib-object.h>
 
 #include "backends/meta-backend-private.h"
-#include "backends/meta-logical-monitor.h"
+#include "backends/meta-logical-monitor-private.h"
 
 enum
 {
