@@ -21,10 +21,10 @@
 
 #include <glib.h>
 
-#include <meta/types.h>
-#include <meta/boxes.h>
-#include <meta/window.h>
-#include <meta/workspace.h>
+#include "meta/types.h"
+#include "meta/boxes.h"
+#include "meta/window.h"
+#include "meta/workspace.h"
 
 #define META_TYPE_COMPOSITOR (meta_compositor_get_type ())
 META_EXPORT
@@ -71,3 +71,24 @@ MetaLaters * meta_compositor_get_laters (MetaCompositor *compositor);
 
 META_EXPORT
 ClutterActor * meta_compositor_get_feedback_group (MetaCompositor *compositor);
+
+META_EXPORT
+MetaBackend * meta_compositor_get_backend (MetaCompositor *compositor);
+
+META_EXPORT
+ClutterStage * meta_compositor_get_stage (MetaCompositor *compositor);
+
+META_EXPORT
+ClutterActor * meta_compositor_get_window_group (MetaCompositor *compositor);
+
+META_EXPORT
+GList * meta_compositor_get_window_actors (MetaCompositor *compositor);
+
+META_EXPORT
+ClutterActor * meta_compositor_get_top_window_group (MetaCompositor *compositor);
+
+META_EXPORT
+void meta_compositor_disable_unredirect (MetaCompositor *compositor);
+
+META_EXPORT
+void meta_compositor_enable_unredirect (MetaCompositor *compositor);
