@@ -195,7 +195,7 @@ meta_test_service_channel_open_wayland_connection (void)
     g_main_context_iteration (NULL, TRUE);
 
   g_debug ("Waiting for thread to terminate");
-  g_thread_join (thread);
+  g_thread_join (g_steal_pointer (&thread));
 }
 
 static void
