@@ -174,15 +174,12 @@ meta_xwayland_surface_get_relative_coordinates (MetaWaylandSurfaceRole *surface_
   MetaXwaylandSurface *xwayland_surface = META_XWAYLAND_SURFACE (surface_role);
   MetaWaylandSurface *surface =
     meta_wayland_surface_role_get_surface (surface_role);
-  MetaWaylandCompositor *compositor =
-    meta_wayland_surface_get_compositor (surface);
   MtkRectangle window_rect = { 0 };
-  int xwayland_scale;
+  int xwayland_scale = surface->applied_state.scale;
 
   if (xwayland_surface->window)
     meta_window_get_buffer_rect (xwayland_surface->window, &window_rect);
 
-  xwayland_scale = meta_xwayland_get_effective_scale (&compositor->xwayland_manager);
   *out_sx = (abs_x - window_rect.x) * xwayland_scale;
   *out_sy = (abs_y - window_rect.y) * xwayland_scale;
 }
