@@ -24,7 +24,7 @@
 #include <X11/Xutil.h>
 #include <X11/extensions/sync.h>
 
-#include "meta/display.h"
+#include "meta/meta-x11-display.h"
 
 /* Copied from Lesstif by way of GTK. Rudimentary docs can be
  * found in some Motif reference guides online.
